androidFastFileContent constant

String const androidFastFileContent

Implementation

static const String androidFastFileContent = '''
# This file contains the fastlane.tools configuration
# You can find the documentation at https://docs.fastlane.tools
#
# For a list of all available actions, check out
#
#     https://docs.fastlane.tools/actions
#
# For a list of all available plugins, check out
#
#     https://docs.fastlane.tools/plugins/available-plugins
#

# Uncomment the line if you want fastlane to automatically update itself
# update_fastlane

default_platform(:android)

platform :android do
desc "Deploy a new version to the Google Play"
lane :new_update do
supply(
  package_name: "%package_name%",
  json_key: "%json_key_path%",
  track: "%track%",
  aab: "../build/app/outputs/bundle/%aab_name%",
  mapping: "../build/app/outputs/mapping/%mapping_name%",
)
end
end

''';