Constants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- androidDeliverfilePath → String
-
no setter
- androidDirPath → String
-
no setter
- androidFastfilePath → String
-
no setter
- androidFastlaneDirPath → String
-
no setter
- androidFastlaneMetadataDirPath → String
-
no setter
- automateConfigFilePath → String
-
no setter
- buildAndroidAabDirPath → String
-
no setter
- buildAndroidMappingDirPath → String
-
no setter
- buildIosIpaDirPath → String
-
no setter
- gitignorePath → String
-
no setter
- iosDeliverfilePath → String
-
no setter
- iosDirPath → String
-
no setter
- iosFastfilePath → String
-
no setter
- iosFastlaneDirPath → String
-
no setter